@@ -32,6 +32,7 @@ fn get_remote_parts(url: &str) -> Result<(&str, &str)> {
 
 const BROWSER: &str = "BROWSER";
 const DEFAULT_REMOTE_ORIGIN: &str = "origin";
+const BITBUCKET_HOSTNAME: &str = "bitbucket.org";
 
 /// Enumeration to store exit codes. The first one, Success is by default set to 0
 enum ExitCode {
@@ -58,15 +59,19 @@ fn main() {
         }
     };
 
-    // Get the branch to show in the browser. If the option is given, then, the
-    // value will be used, else, the current branch is given, or master if
-    // something went wrong.
-    let branch = match opt.branch {
-        Some(branch) => branch,
-        None => {
-            logger.verbose_print("No branch given, getting current one");
+    // Get the tag to show in the browser. If the option is given, then the value
+    // will be used as it is an alias for branch.
+    let reference = if let Some(tag) = opt.tag { tag } else {
+        // Get the branch to show in the browser. If the option is given, then, the
+        // value will be used, else, the current branch is given, or master if
+        // something went wrong.
+        match opt.branch {
+            Some(branch) => branch,
+            None => {
+                logger.verbose_print("No branch given, getting current one");
 
-            git::get_branch(&repo, &logger)
+                git::get_branch(&repo, &logger)
+            }
         }
     };
 
@@ -94,12 +99,23 @@ fn main() {
 
     let parts = get_remote_parts(remote_url).unwrap();
 
-    let url = format!(
-        "https://{domain}/{repository}/tree/{branch}",
-        domain = parts.0,
-        repository = parts.1,
-        branch = branch
-    );
+    let url = if let Some(commit) = opt.commit {
+        format!(
+            "https://{domain}/{repository}/{path}/{commit}",
+            domain = parts.0,
+            path = if parts.0 == BITBUCKET_HOSTNAME {"commits"} else {"commit"},
+            repository = parts.1,
+            commit = commit
+        )
+    } else {
+        format!(
+            "https://{domain}/{repository}/{path}/{reference}",
+            domain = parts.0,
+            path = if parts.0 == BITBUCKET_HOSTNAME {"src"} else {"tree"},
+            repository = parts.1,
+            reference = reference
+        )
+    };
 
     // If the option is available through the command line, open the given one
     match opt.browser {
