@@ -6,7 +6,7 @@ use structopt::StructOpt;
 // Rename all will use the name of the field
 #[structopt(rename_all = "kebab-case")]
 pub struct Opt {
-    /// Set the branch
+    /// Set the branch (alias for --tag)
     ///
     /// By setting the branch, you can override the default behavior that will
     /// set the branch to the current one in the repository. If something went
@@ -14,6 +14,21 @@ pub struct Opt {
     #[structopt(short, long)]
     pub branch: Option<String>,
 
+    /// Set the tag (alias for --branch).
+    ///
+    /// By setting the tag, you can override the default behavior that will set
+    /// the branch to the current one in the repository and will instead take
+    /// the reference tag (or branch) given as parameter.
+    #[structopt(short, long)]
+    pub tag: Option<String>,
+
+    /// Set a commit
+    ///
+    /// By setting a commit, you can override the default behavior that will
+    /// set the branch to the current one in the repository.
+    #[structopt(short, long)]
+    pub commit: Option<String>,
+
     /// Set the browser
     ///
     /// If you set the browser option, it will override the other configuration.
